@@ -17,20 +17,19 @@ To access these members use directly :mod:`tango` module and NOT
 tango.attribute_proxy.
 """
 
-__all__ = [ "AttributeProxy", "attribute_proxy_init", "get_attribute_proxy" ]
-
-__docformat__ = "restructuredtext"
-
 import collections
 
 from ._tango import StdStringVector, DbData, DbDatum, DeviceProxy
 from ._tango import __AttributeProxy as _AttributeProxy
 from .utils import seq_2_StdStringVector, seq_2_DbData, DbData_2_dict
 from .utils import is_pure_str, is_non_str_seq
-from .green import result, submit, get_green_mode, get_wait_default_value
+from .green import green, get_green_mode
 from .device_proxy import __init_device_proxy_internals as init_device_proxy
 
+__all__ = ["AttributeProxy", "attribute_proxy_init", "get_attribute_proxy"]
 
+
+@green(consume_green_mode=True)
 def get_attribute_proxy(*args, **kwargs):
     """
     get_attribute_proxy(self, full_attr_name, green_mode=None, wait=True, timeout=True) -> AttributeProxy
@@ -81,14 +80,8 @@ def get_attribute_proxy(*args, **kwargs):
 
     New in PyTango 8.1.0
     """
-    # we cannot use the green wrapper because it consumes the green_mode and we
-    # want to forward it to the DeviceProxy constructor
-    green_mode = kwargs.get('green_mode', get_green_mode())
-    wait = kwargs.pop('wait', get_wait_default_value(green_mode))
-    timeout = kwargs.pop('timeout', None)
+    return AttributeProxy(*args, **kwargs)
 
-    d = submit(green_mode, AttributeProxy, *args, **kwargs)
-    return result(d, green_mode, wait=wait, timeout=timeout)
 
 def __AttributeProxy__get_property(self, propname, value=None):
     """
@@ -141,7 +134,8 @@ def __AttributeProxy__get_property(self, propname, value=None):
 
         if is_pure_str(propname[0]):
             new_propname = StdStringVector()
-            for i in propname: new_propname.append(i)
+            for i in propname:
+                new_propname.append(i)
             new_value = value
             if new_value is None:
                 new_value = DbData()
@@ -149,10 +143,12 @@ def __AttributeProxy__get_property(self, propname, value=None):
             return DbData_2_dict(new_value)
         elif isinstance(propname[0], DbDatum):
             new_value = DbData()
-            for i in propname: new_value.append(i)
+            for i in propname:
+                new_value.append(i)
             self._get_property(new_value)
             return DbData_2_dict(new_value)
 
+
 def __AttributeProxy__put_property(self, value):
     """
     put_property(self, value) -> None
@@ -202,10 +198,12 @@ def __AttributeProxy__put_property(self, value):
             new_value.append(db_datum)
         value = new_value
     else:
-        raise TypeError('value must be a tango.DbDatum, tango.DbData,'\
-                        'a sequence<DbDatum> or a dictionary')
+        raise TypeError(
+            'Value must be a tango.DbDatum, tango.DbData, '
+            'a sequence<DbDatum> or a dictionary')
     return self._put_property(value)
 
+
 def __AttributeProxy__delete_property(self, value):
     """
     delete_property(self, value) -> None
@@ -242,7 +240,7 @@ def __AttributeProxy__delete_property(self, value):
                     DevFailed from device (DB_SQLError)
     """
     if isinstance(value, DbData) or isinstance(value, StdStringVector) or \
-       is_pure_str(value):
+            is_pure_str(value):
         new_value = value
     elif isinstance(value, DbDatum):
         new_value = DbData()
@@ -262,11 +260,13 @@ def __AttributeProxy__delete_property(self, value):
             else:
                 new_value.append(DbDatum(k))
     else:
-        raise TypeError('value must be a string, tango.DbDatum, '\
-                        'tango.DbData, a sequence or a dictionary')
+        raise TypeError(
+            'Value must be a string, tango.DbDatum, '
+            'tango.DbData, a sequence or a dictionary')
 
     return self._delete_property(new_value)
 
+
 # It is easier to reimplement AttributeProxy in python using DeviceProxy than
 # wrapping C++ AttributeProxy. However I still rely in the original
 # AttributeProxy for the constructor (parsing strings if necessary) and some
@@ -288,6 +288,7 @@ class AttributeProxy(object):
         Note: PyTango implementation of AttributeProxy is in part a
         python reimplementation of the AttributeProxy found on the C++ API.
     """
+
     def __init__(self, *args, **kwds):
         green_mode = kwds.pop('green_mode', get_green_mode())
         self.__attr_proxy = _AttributeProxy(*args, **kwds)
@@ -326,90 +327,97 @@ class AttributeProxy(object):
     def __repr__(self):
         return "AttributeProxy(%s)" % self.name()
 
+
 def _method_dev_and_name(dp_fn_name, doc=True):
     def __new_fn(self, *args, **kwds):
         return getattr(self._AttributeProxy__dev_proxy, dp_fn_name)(self.name(), *args, **kwds)
+
     if doc:
-        __new_fn.__doc__ =  "This method is a simple way to do:\n" + \
-                            "\tself.get_device_proxy()."+dp_fn_name+ \
-                            "(self.name(), ...)\n\n" + \
-                            "For convenience, here is the documentation of DeviceProxy." + \
-                            dp_fn_name + "(...):\n" + \
-                            str(getattr(DeviceProxy, dp_fn_name).__doc__)
+        __new_fn.__doc__ = "This method is a simple way to do:\n" + \
+                           "\tself.get_device_proxy()." + dp_fn_name + \
+                           "(self.name(), ...)\n\n" + \
+                           "For convenience, here is the documentation of DeviceProxy." + \
+                           dp_fn_name + "(...):\n" + \
+                           str(getattr(DeviceProxy, dp_fn_name).__doc__)
     __new_fn.__name__ = dp_fn_name
     return __new_fn
 
+
 def _method_device(dp_fn_name, doc=True):
     def __new_fn(self, *args, **kwds):
         return getattr(self._AttributeProxy__dev_proxy, dp_fn_name)(*args, **kwds)
+
     if doc:
-        __new_fn.__doc__ =  "This method is a simple way to do:\n" + \
-                            "\tself.get_device_proxy()."+dp_fn_name+ \
-                            "(...)\n\n" + \
-                            "For convenience, here is the documentation of DeviceProxy." + \
-                            dp_fn_name + "(...):\n" + \
-                            str(getattr(DeviceProxy, dp_fn_name).__doc__)
+        __new_fn.__doc__ = "This method is a simple way to do:\n" + \
+                           "\tself.get_device_proxy()." + dp_fn_name + \
+                           "(...)\n\n" + \
+                           "For convenience, here is the documentation of DeviceProxy." + \
+                           dp_fn_name + "(...):\n" + \
+                           str(getattr(DeviceProxy, dp_fn_name).__doc__)
     __new_fn.__name__ = dp_fn_name
     return __new_fn
 
+
 def _method_attribute(dp_fn_name, doc=True):
     def __new_fn(self, *args, **kwds):
         return getattr(self._AttributeProxy__attr_proxy, dp_fn_name)(*args, **kwds)
+
     if doc:
-        __new_fn.__doc__ =  getattr(_AttributeProxy, dp_fn_name).__doc__
+        __new_fn.__doc__ = getattr(_AttributeProxy, dp_fn_name).__doc__
     __new_fn.__name__ = dp_fn_name
     return __new_fn
 
-def __init_AttributeProxy(doc=True):
 
-    _AttributeProxy.get_property        = __AttributeProxy__get_property
-    _AttributeProxy.put_property        = __AttributeProxy__put_property
-    _AttributeProxy.delete_property     = __AttributeProxy__delete_property
+def __init_AttributeProxy(doc=True):
+    _AttributeProxy.get_property = __AttributeProxy__get_property
+    _AttributeProxy.put_property = __AttributeProxy__put_property
+    _AttributeProxy.delete_property = __AttributeProxy__delete_property
 
     # General methods
-    #AttributeProxy.name                manually defined
-    AttributeProxy.status               = _method_device('status', doc=doc)
-    AttributeProxy.state                = _method_device('state', doc=doc)
-    AttributeProxy.ping                 = _method_device('ping', doc=doc)
-    AttributeProxy.get_transparency_reconnection=_method_device('get_transparency_reconnection', doc=doc)
-    AttributeProxy.set_transparency_reconnection=_method_device('set_transparency_reconnection', doc=doc)
+    # AttributeProxy.name                manually defined
+    AttributeProxy.status = _method_device('status', doc=doc)
+    AttributeProxy.state = _method_device('state', doc=doc)
+    AttributeProxy.ping = _method_device('ping', doc=doc)
+    AttributeProxy.get_transparency_reconnection = _method_device('get_transparency_reconnection', doc=doc)
+    AttributeProxy.set_transparency_reconnection = _method_device('set_transparency_reconnection', doc=doc)
 
     # Property methods
-    AttributeProxy.get_property         = _method_attribute('get_property', doc=doc)
-    AttributeProxy.put_property         = _method_attribute('put_property', doc=doc)
-    AttributeProxy.delete_property      = _method_attribute('delete_property', doc=doc)
+    AttributeProxy.get_property = _method_attribute('get_property', doc=doc)
+    AttributeProxy.put_property = _method_attribute('put_property', doc=doc)
+    AttributeProxy.delete_property = _method_attribute('delete_property', doc=doc)
 
     # Attribute methods
-    AttributeProxy.get_config           = _method_dev_and_name('get_attribute_config', doc=doc)
-    AttributeProxy.set_config           = _method_device('set_attribute_config', doc=doc)
+    AttributeProxy.get_config = _method_dev_and_name('get_attribute_config', doc=doc)
+    AttributeProxy.set_config = _method_device('set_attribute_config', doc=doc)
 
-    AttributeProxy.write                = _method_dev_and_name('write_attribute', doc=doc)
-    AttributeProxy.read                 = _method_dev_and_name('read_attribute', doc=doc)
-    AttributeProxy.write_read           = _method_dev_and_name('write_read_attribute', doc=doc)
+    AttributeProxy.write = _method_dev_and_name('write_attribute', doc=doc)
+    AttributeProxy.read = _method_dev_and_name('read_attribute', doc=doc)
+    AttributeProxy.write_read = _method_dev_and_name('write_read_attribute', doc=doc)
 
     # History methods...
-    AttributeProxy.history              = _method_dev_and_name('attribute_history', doc=doc)
+    AttributeProxy.history = _method_dev_and_name('attribute_history', doc=doc)
 
     # Polling administration methods
-    AttributeProxy.poll                 = _method_dev_and_name('poll_attribute', doc=doc)
-    AttributeProxy.get_poll_period      = _method_dev_and_name('get_attribute_poll_period', doc=doc)
-    AttributeProxy.is_polled            = _method_dev_and_name('is_attribute_polled', doc=doc)
-    AttributeProxy.stop_poll            = _method_dev_and_name('stop_poll_attribute', doc=doc)
+    AttributeProxy.poll = _method_dev_and_name('poll_attribute', doc=doc)
+    AttributeProxy.get_poll_period = _method_dev_and_name('get_attribute_poll_period', doc=doc)
+    AttributeProxy.is_polled = _method_dev_and_name('is_attribute_polled', doc=doc)
+    AttributeProxy.stop_poll = _method_dev_and_name('stop_poll_attribute', doc=doc)
 
     # Asynchronous methods
-    AttributeProxy.read_asynch          = _method_dev_and_name('read_attribute_asynch', doc=doc)
-    AttributeProxy.read_reply           = _method_device('read_attribute_reply', doc=doc)
-    AttributeProxy.write_asynch         = _method_device('write_attribute_asynch', doc=doc)
-    AttributeProxy.write_reply          = _method_device('write_attribute_reply', doc=doc)
+    AttributeProxy.read_asynch = _method_dev_and_name('read_attribute_asynch', doc=doc)
+    AttributeProxy.read_reply = _method_device('read_attribute_reply', doc=doc)
+    AttributeProxy.write_asynch = _method_device('write_attribute_asynch', doc=doc)
+    AttributeProxy.write_reply = _method_device('write_attribute_reply', doc=doc)
 
     # Event methods
-    AttributeProxy.subscribe_event      = _method_dev_and_name('subscribe_event', doc=doc)
-    AttributeProxy.unsubscribe_event    = _method_device('unsubscribe_event', doc=doc)
+    AttributeProxy.subscribe_event = _method_dev_and_name('subscribe_event', doc=doc)
+    AttributeProxy.unsubscribe_event = _method_device('unsubscribe_event', doc=doc)
 
-    AttributeProxy.get_events           = _method_device('get_events', doc=doc)
-    AttributeProxy.event_queue_size     = _method_device('event_queue_size', doc=doc)
-    AttributeProxy.get_last_event_date  = _method_device('get_last_event_date', doc=doc)
+    AttributeProxy.get_events = _method_device('get_events', doc=doc)
+    AttributeProxy.event_queue_size = _method_device('event_queue_size', doc=doc)
+    AttributeProxy.get_last_event_date = _method_device('get_last_event_date', doc=doc)
     AttributeProxy.is_event_queue_empty = _method_device('is_event_queue_empty', doc=doc)
 
+
 def attribute_proxy_init(doc=True):
     __init_AttributeProxy(doc=doc)
