@@ -16,7 +16,6 @@ from __future__ import print_function
 from __future__ import absolute_import
 
 import sys
-import six
 import copy
 import inspect
 import logging
@@ -24,7 +23,7 @@ import functools
 import traceback
 
 from ._tango import AttrDataFormat, AttrWriteType, CmdArgType, PipeWriteType
-from ._tango import DevFailed, Except, GreenMode
+from ._tango import DevFailed, GreenMode, SerialModel
 
 from .attr_data import AttrData
 from .pipe_data import PipeData
@@ -32,14 +31,30 @@ from .device_class import DeviceClass
 from .device_server import LatestDeviceImpl
 from .utils import is_seq, is_non_str_seq
 from .utils import scalar_to_array_type, TO_TANGO_TYPE
+from .green import get_green_mode, get_executor
+from .pyutil import Util
 
 __all__ = ["DeviceMeta", "Device", "LatestDeviceImpl", "attribute",
            "command", "pipe", "device_property", "class_property",
-           "run", "server_run", "get_worker", "get_async_worker",
-           "Server"]
+           "run", "server_run", "Server"]
 
 API_VERSION = 2
 
+# Worker access
+
+_WORKER = get_executor()
+
+
+def set_worker(worker):
+    global _WORKER
+    _WORKER = worker
+
+
+def get_worker():
+    return _WORKER
+
+
+# Helpers
 
 def _get_tango_type_format(dtype=None, dformat=None):
     if dformat is None:
@@ -283,17 +298,13 @@ def _get_wrapped_pipe_write_method(pipe, write_method):
     if green_mode == GreenMode.Synchronous:
         @functools.wraps(write_method)
         def write_pipe(self, pipe):
-            # TODO
-            raise NotImplementedError
-            # value = pipe.get_write_value()
-            # return write_method(self, value)
+            value = pipe.get_value()
+            return write_method(self, value)
     else:
         @functools.wraps(write_method)
         def write_pipe(self, pipe):
-            # TODO
-            raise NotImplementedError
-            # value = pipe.get_write_value()
-            # return get_worker().execute(write_method, self, value)
+            value = pipe.get_value()
+            return get_worker().execute(write_method, self, value)
     return write_pipe
 
 
@@ -347,6 +358,7 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(init_device_orig)
     def init_device(self):
         return get_worker().execute(init_device_orig, self)
+
     setattr(klass, "init_device", init_device)
 
     delete_device_orig = klass.delete_device
@@ -354,6 +366,7 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(delete_device_orig)
     def delete_device(self):
         return get_worker().execute(delete_device_orig, self)
+
     setattr(klass, "delete_device", delete_device)
 
     dev_state_orig = klass.dev_state
@@ -361,6 +374,7 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(dev_state_orig)
     def dev_state(self):
         return get_worker().execute(dev_state_orig, self)
+
     setattr(klass, "dev_state", dev_state)
 
     dev_status_orig = klass.dev_status
@@ -368,6 +382,7 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(dev_status_orig)
     def dev_status(self):
         return get_worker().execute(dev_status_orig, self)
+
     setattr(klass, "dev_status", dev_status)
 
     read_attr_hardware_orig = klass.read_attr_hardware
@@ -375,6 +390,7 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(read_attr_hardware_orig)
     def read_attr_hardware(self, attr_list):
         return get_worker().execute(read_attr_hardware_orig, self, attr_list)
+
     setattr(klass, "read_attr_hardware", read_attr_hardware)
 
     always_executed_hook_orig = klass.always_executed_hook
@@ -382,11 +398,11 @@ def __patch_standard_device_methods(klass):
     @functools.wraps(always_executed_hook_orig)
     def always_executed_hook(self):
         return get_worker().execute(always_executed_hook_orig, self)
+
     setattr(klass, "always_executed_hook", always_executed_hook)
 
 
 class _DeviceClass(DeviceClass):
-
     def __init__(self, name):
         DeviceClass.__init__(self, name)
         self.set_type(name)
@@ -434,7 +450,8 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
             else:
                 attr_name = attr_obj.attr_name
             attr_list[attr_name] = attr_obj
-            __patch_attr_methods(tango_device_klass, attr_obj)
+            if not attr_obj.forward:
+                __patch_attr_methods(tango_device_klass, attr_obj)
         elif isinstance(attr_obj, pipe):
             if attr_obj.pipe_name is None:
                 attr_obj._set_name(attr_name)
@@ -444,9 +461,12 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
             __patch_pipe_methods(tango_device_klass, attr_obj)
         elif isinstance(attr_obj, device_property):
             attr_obj.name = attr_name
+            # if you modify the attr_obj order then you should
+            # take care of the code in get_device_properties()
             device_property_list[attr_name] = [attr_obj.dtype,
                                                attr_obj.doc,
-                                               attr_obj.default_value]
+                                               attr_obj.default_value,
+                                               attr_obj.mandatory]
         elif isinstance(attr_obj, class_property):
             attr_obj.name = attr_name
             class_property_list[attr_name] = [attr_obj.dtype,
@@ -465,11 +485,11 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
                           device_property_list=device_property_list,
                           cmd_list=cmd_list, attr_list=attr_list,
                           pipe_list=pipe_list)
-    return type(devclass_name, (_DeviceClass,), devclass_attrs)
+    return type(_DeviceClass)(devclass_name, (_DeviceClass,), devclass_attrs)
 
 
 def _init_tango_device_klass(tango_device_klass, attrs=None,
-                              tango_class_name=None):
+                             tango_class_name=None):
     klass_name = tango_device_klass.__name__
     tango_deviceclass_klass = __create_tango_deviceclass_klass(
         tango_device_klass, attrs=attrs)
@@ -558,6 +578,7 @@ class BaseDevice(LatestDeviceImpl):
 
     def delete_device(self):
         pass
+
     delete_device.__doc__ = LatestDeviceImpl.delete_device.__doc__
 
     def read_attr_hardware(self, attr_list):
@@ -591,8 +612,13 @@ class BaseDevice(LatestDeviceImpl):
                 value = self.prop_util.get_property_values(
                     prop_name, self.device_property_list)
                 self._tango_properties[prop_name] = value
+                properties = self.device_property_list[prop_name]
+                mandatory = properties[3]
+                if mandatory and value is None:
+                    msg = "Device property {0} is mandatory ".format(prop_name)
+                    raise Exception(msg)
         except DevFailed as df:
-            print(80*"-")
+            print(80 * "-")
             print(df)
             raise df
 
@@ -674,7 +700,7 @@ class attribute(AttrData):
     access                 :obj:`~tango.AttrWriteType`      :obj:`~tango.AttrWriteType.READ`        read only/ read write / write only access
     fget (or fread)        :obj:`str` or :obj:`callable`    'read_<attr_name>'                      read method name or method object
     fset (or fwrite)       :obj:`str` or :obj:`callable`    'write_<attr_name>'                     write method name or method object
-    is_allowed             :obj:`str` or :obj:`callable`    'is_<attr_name>_allowed'                is allowed method name or method object
+    fisallowed             :obj:`str` or :obj:`callable`    'is_<attr_name>_allowed'                is allowed method name or method object
     label                  :obj:`str`                       '<attr_name>'                           attribute label
     enum_labels            sequence                         None                                    the list of enumeration labels (enum data type)
     doc (or description)   :obj:`str`                       ''                                      attribute description
@@ -699,6 +725,7 @@ class attribute(AttrData):
     green_mode             :obj:`~tango.GreenMode`          None                                    green mode for read and write. None means use server green mode.
     read_green_mode        :obj:`~tango.GreenMode`          None                                    green mode for read. None means use server green mode.
     write_green_mode       :obj:`~tango.GreenMode`          None                                    green mode for write. None means use server green mode.
+    forwarded              :obj:`bool`                      False                                   the attribute should be forwarded if True
     ===================== ================================ ======================================= =======================================================================================
 
     .. note::
@@ -750,21 +777,27 @@ class attribute(AttrData):
 
     def __init__(self, fget=None, **kwargs):
         self._kwargs = dict(kwargs)
-        name = kwargs.pop("name", None)
+        self.name = kwargs.pop("name", None)
         class_name = kwargs.pop("class_name", None)
-        green_mode = kwargs.pop("green_mode", True)
-        self.read_green_mode = kwargs.pop("read_green_mode", green_mode)
-        self.write_green_mode = kwargs.pop("write_green_mode", green_mode)
+        forward = kwargs.get("forwarded", False)
+        if forward:
+            expected = 2 if "label" in kwargs else 1
+            if len(kwargs) > expected:
+                raise TypeError(
+                    "Forwarded attributes only support label argument")
+        else:
+            green_mode = kwargs.pop("green_mode", True)
+            self.read_green_mode = kwargs.pop("read_green_mode", green_mode)
+            self.write_green_mode = kwargs.pop("write_green_mode", green_mode)
 
-        if fget:
-            if inspect.isroutine(fget):
-                self.fget = fget
-                if 'doc' not in kwargs and 'description' not in kwargs:
-                    if fget.__doc__ is not None:
-                        kwargs['doc'] = fget.__doc__
-            kwargs['fget'] = fget
-
-        super(attribute, self).__init__(name, class_name)
+            if fget:
+                if inspect.isroutine(fget):
+                    self.fget = fget
+                    if 'doc' not in kwargs and 'description' not in kwargs:
+                        if fget.__doc__ is not None:
+                            kwargs['doc'] = fget.__doc__
+                kwargs['fget'] = fget
+        super(attribute, self).__init__(self.name, class_name)
         self.__doc__ = kwargs.get('doc', kwargs.get('description',
                                                     'TANGO attribute'))
         if 'dtype' in kwargs:
@@ -859,7 +892,7 @@ class pipe(PipeData):
     access                 :obj:`~tango.PipeWriteType`      :obj:`~tango.PipeWriteType.READ`        read only/ read write access
     fget (or fread)        :obj:`str` or :obj:`callable`    'read_<pipe_name>'                      read method name or method object
     fset (or fwrite)       :obj:`str` or :obj:`callable`    'write_<pipe_name>'                     write method name or method object
-    is_allowed             :obj:`str` or :obj:`callable`    'is_<pipe_name>_allowed'                is allowed method name or method object
+    fisallowed             :obj:`str` or :obj:`callable`    'is_<pipe_name>_allowed'                is allowed method name or method object
     label                  :obj:`str`                       '<pipe_name>'                           pipe label
     doc (or description)   :obj:`str`                       ''                                      pipe description
     green_mode             :obj:`~tango.GreenMode`          None                                    green mode for read and write. None means use server green mode.
@@ -928,9 +961,6 @@ class pipe(PipeData):
         self.__doc__ = kwargs.get('doc', kwargs.get('description',
                                                     'TANGO pipe'))
         self.build_from_dict(kwargs)
-        if self.pipe_write == PipeWriteType.PIPE_READ_WRITE:
-            raise NotImplementedError(
-                'writtable pipes not implemented in 9.2.0a')
 
     def get_pipe(self, obj):
         dclass = obj.get_device_class()
@@ -954,7 +984,6 @@ class pipe(PipeData):
         To be used as a decorator. Will define the decorated method
         as a write pipe method to be called when client writes to the pipe
         """
-        raise NotImplementedError('writtable pipes not implemented in 9.2.0a')
         self.fset = fset
         self.pipe_write = PipeWriteType.PIPE_READ_WRITE
         return self
@@ -1107,10 +1136,8 @@ def command(f=None, dtype_in=None, dformat_in=None, doc_in="",
 
 
 class _BaseProperty(object):
-
     def __init__(self, dtype, doc='', default_value=None, update_db=False):
         self.name = None
-        self.__value = None
         dtype = from_typeformat_to_type(*_get_tango_type_format(dtype))
         self.dtype = dtype
         self.doc = doc
@@ -1147,9 +1174,11 @@ class device_property(_BaseProperty):
         class PowerSupply(Device):
 
             host = device_property(dtype=str)
+            port = device_property(dtype=int, mandatory=True)
 
     :param dtype: Data type (see :ref:`pytango-data-types`)
     :param doc: property documentation (optional)
+    :param mandatory (optional: default is False)
     :param default_value: default value for the property (optional)
     :param update_db: tells if set value should write the value to database.
                      [default: False]
@@ -1158,7 +1187,15 @@ class device_property(_BaseProperty):
     .. versionadded:: 8.1.7
         added update_db option
     """
-    pass
+    def __init__(self, dtype, doc='', mandatory=False,
+                 default_value=None, update_db=False):
+        super(device_property, self).__init__(dtype, doc, default_value,
+                                              update_db)
+        self.mandatory = mandatory
+        if mandatory and default_value is not None:
+            msg = "device_property arguments mandatory " \
+                  "and default_value are incompatible"
+            raise Exception(msg)
 
 
 class class_property(_BaseProperty):
@@ -1262,15 +1299,9 @@ def __server_run(classes, args=None, msg_stream=sys.stdout, util=None,
                  event_loop=None, post_init_callback=None,
                  green_mode=None):
     if green_mode is None:
-        from tango import get_green_mode
         green_mode = get_green_mode()
-    async_mode = green_mode in (GreenMode.Gevent, GreenMode.Asyncio)
 
-    import tango
-    if msg_stream is None:
-        write = lambda msg: None
-    else:
-        write = msg_stream.write
+    write = msg_stream.write if msg_stream else lambda msg: None
 
     if args is None:
         args = sys.argv
@@ -1278,18 +1309,16 @@ def __server_run(classes, args=None, msg_stream=sys.stdout, util=None,
     post_init_callback = __to_cb(post_init_callback)
 
     if util is None:
-        util = tango.Util(args)
+        util = Util(args)
 
-    if async_mode:
-        util.set_serial_model(tango.SerialModel.NO_SYNC)
-        worker = _create_async_worker(green_mode)
-        set_worker(worker)
+    if green_mode in (GreenMode.Gevent, GreenMode.Asyncio):
+        util.set_serial_model(SerialModel.NO_SYNC)
 
-    worker = get_worker()
+    worker = get_executor(green_mode)
+    set_worker(worker)
 
     if event_loop is not None:
-        if async_mode:
-            event_loop = functools.partial(worker.execute, event_loop)
+        event_loop = functools.partial(worker.execute, event_loop)
         util.server_set_event_loop(event_loop)
 
     log = logging.getLogger("tango")
@@ -1301,22 +1330,16 @@ def __server_run(classes, args=None, msg_stream=sys.stdout, util=None,
         worker.execute(post_init_callback)
         write("Ready to accept request\n")
         util.server_run()
-        worker.stop()
         log.debug("server loop exit")
 
-    if async_mode:
-        task = worker.run_in_thread(tango_loop)
-        worker.run(task)
-        log.debug("async worker finished")
-    else:
-        tango_loop()
-
+    worker.run(tango_loop, wait=True)
     return util
 
 
 def run(classes, args=None, msg_stream=sys.stdout,
         verbose=False, util=None, event_loop=None,
-        post_init_callback=None, green_mode=None):
+        post_init_callback=None, green_mode=None,
+        raises=False):
     """
     Provides a simple way to run a tango server. It handles exceptions
     by writting a message to the msg_stream.
@@ -1425,6 +1448,10 @@ def run(classes, args=None, msg_stream=sys.stdout,
     :type post_init_callback:
         callable or tuple (see description above)
 
+    :param raises:
+        Disable error handling and propagate exceptions from the server
+    :type raises: bool
+
     :return: The Util singleton object
     :rtype: :class:`~tango.Util`
 
@@ -1433,16 +1460,23 @@ def run(classes, args=None, msg_stream=sys.stdout,
     .. versionchanged:: 8.1.4
         when classes argument is a sequence, the items can also be
         a sequence <TangoClass, TangoClassClass>[, tango class name]
+
+    .. versionchanged:: 9.2.2
+        `raises` argument has been added
     """
-    if msg_stream is None:
-        write = lambda msg: None
-    else:
-        write = msg_stream.write
+    server_run = functools.partial(
+        __server_run, classes,
+        args=args, msg_stream=msg_stream,
+        util=util, event_loop=event_loop,
+        post_init_callback=post_init_callback,
+        green_mode=green_mode)
+    # Run the server without error handling
+    if raises:
+        return server_run()
+    # Run the server with error handling
+    write = msg_stream.write if msg_stream else lambda msg: None
     try:
-        return __server_run(classes, args=args, msg_stream=msg_stream,
-                            util=util, event_loop=event_loop,
-                            post_init_callback=post_init_callback,
-                            green_mode=green_mode)
+        return server_run()
     except KeyboardInterrupt:
         write("Exiting: Keyboard interrupt\n")
     except DevFailed as df:
@@ -1490,207 +1524,12 @@ def server_run(classes, args=None, msg_stream=sys.stdout,
                green_mode=green_mode)
 
 
-class BaseWorker:
-    def __init__(self, max_queue_size=0):
-        pass
-
-    def execute(self, func, *args, **kwargs):
-        return func(*args, **kwargs)
-
-    def stop(self):
-        pass
-
-
-__WORKER = BaseWorker()
-__ASYNC_WORKER = None
-
-def get_worker():
-    global __WORKER
-    return __WORKER
-
-
-def set_worker(worker):
-    global __WORKER
-    __WORKER = worker
-
-
-def get_async_worker():
-    global __ASYNC_WORKER
-    return __ASYNC_WORKER
-
-
-def _create_async_worker(green_mode):
-    global __ASYNC_WORKER
-    if __ASYNC_WORKER:
-        return __ASYNC_WORKER
-    if green_mode == GreenMode.Gevent:
-        _ASYNC_WORKER = _create_gevent_worker()
-    if green_mode == GreenMode.Asyncio:
-        _ASYNC_WORKER = _create_asyncio_worker()
-    return _ASYNC_WORKER
-
-
-def _create_gevent_worker():
-    try:
-        from queue import Queue
-    except:
-        from Queue import Queue
-    from threading import current_thread
-
-    import gevent
-    import gevent.event
-    import gevent._threading
-
-    class GeventWorker(BaseWorker):
-
-        class Task:
-
-            def __init__(self, event, func, *args, **kwargs):
-                self.__event = event
-                self.__func = func
-                self.__args = args
-                self.__kwargs = kwargs
-                self.value = None
-                self.exception = None
-
-            def __call__(self):
-                func = self.__func
-                if func:
-                    try:
-                        self.value = func(*self.__args, **self.__kwargs)
-                    except:
-                        self.exception = sys.exc_info()
-                self.__event.set()
-
-            def run(self):
-                return gevent.spawn(self)
-
-        def __init__(self, max_queue_size=0):
-            self.__tasks = Queue(max_queue_size)
-            self.__stop_event = gevent.event.Event()
-            self.__watcher = gevent.get_hub().loop.async()
-            self.__watcher.start(self.__step)
-            self.__lock = gevent._threading.Lock()
-            self.__id = id(current_thread())
-
-        def __step(self):
-            task = self.__tasks.get()
-            return task.run()
-
-        def is_gevent_thread(self):
-            return self.__id == id(current_thread())
-
-        def run_in_thread(self, func, *args, **kwargs):
-            return gevent.get_hub().threadpool.spawn(func, *args, **kwargs)
-
-        def run(self, until=None, timeout=None):
-            if until is not None:
-                objects = until, self.__stop_event
-            else:
-                objects = self.__stop_event,
-            return gevent.wait(objects=objects, timeout=timeout)
-
-        def execute(self, func, *args, **kwargs):
-            if self.is_gevent_thread():
-                return func(*args, **kwargs)
-            event = gevent._threading.Event()
-            task = self.Task(event, func, *args, **kwargs)
-            with self.__lock:
-                self.__tasks.put(task)
-                self.__watcher.send()
-                event.wait()
-            if task.exception:
-                if issubclass(task.exception[0], DevFailed):
-                    raise task.exception[1]
-                else:
-                    Except.throw_python_exception(*task.exception)
-            return task.value
-
-        def stop(self):
-            task = self.Task(self.__stop_event, None)
-            self.__tasks.put(task)
-            self.__watcher.send()
-
-    return GeventWorker()
-
-
-def _create_asyncio_worker():
-    import concurrent.futures
-
-    try:
-        from threading import get_ident
-    except:
-        from threading import _get_ident as get_ident
-
-    try:
-        import asyncio
-    except ImportError:
-        import trollius as asyncio
-
-    try:
-        from asyncio import run_coroutine_threadsafe
-    except ImportError:
-        from .asyncio_tools import run_coroutine_threadsafe
-
-    class LoopExecutor(concurrent.futures.Executor):
-        """An Executor subclass that uses an event loop
-        to execute calls asynchronously."""
-
-        def __init__(self, loop=None):
-            """Initialize the executor with a given loop."""
-            self.loop = loop or asyncio.get_event_loop()
-
-        def submit(self, corofn, *args, **kwargs):
-            """Schedule a coroutine, to be executed as corofn(*args **kwargs).
-            Return a Future representing the execution of the callable."""
-            return run_coroutine_threadsafe(corofn(*args, **kwargs), self.loop)
-
-        def run_in_thread(self, func, *args, **kwargs):
-            """Schedule a blocking callback."""
-            callback = lambda: func(*args, **kwargs)
-            coro = self.loop.run_in_executor(None, callback)
-            # That is not actually necessary since coro is actually
-            # a future. But it is an implementation detail and it
-            # might be changed later on.
-            return asyncio.async(coro)
-
-        def run(self, until=None, timeout=None):
-            """Run the asyncio event loop."""
-            if until is None and timeout is None:
-                return self.loop.run_forever()
-            if until is None:
-                until = asyncio.sleep(timeout, loop=self.loop)
-            return self.loop.run_until_complete(until)
-
-        def stop(self):
-            """Run the asyncio event loop."""
-            self.loop.stop()
-
-        def execute(self, fn, *args, **kwargs):
-            """Execute the callable fn as fn(*args **kwargs)."""
-            corofn = asyncio.coroutine(lambda: fn(*args, **kwargs))
-            if self.loop._thread_id == get_ident():
-                return corofn()
-            return self.submit(corofn).result()
-
-    try:
-        loop = asyncio.get_event_loop()
-    except RuntimeError:
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-    return LoopExecutor(loop=loop)
-
-
 # Instanciate DeviceMeta using BaseDevice
-@six.add_metaclass(DeviceMeta)
-class Device(BaseDevice):
-    """
+Device = DeviceMeta("Device", (BaseDevice,), {'__doc__': """\
     Device class for the high-level API.
 
     All device specific classes should inherit from this class.
-    """
-    pass
-
+    """})
 
 # Avoid circular imports
-from .tango_object import Server
+from .tango_object import Server  # noqa: E402
