@@ -24,12 +24,12 @@ from .attr_data import AttrData
 from .utils import TO_TANGO_TYPE
 from ._tango import AttrDataFormat, CmdArgType, GreenMode
 from ._tango import DbDevInfo, Database, DevState, constants
-from .server import Device, DeviceMeta, _to_classes, _add_classes
-from .server import _create_async_worker, get_worker, set_worker
+from .server import Device, _to_classes, _add_classes
+from .server import get_worker, set_worker
+from .green import get_executor
 
 __all__ = ['Server']
 
-
 _CLEAN_UP_TEMPLATE = """
 import sys
 from tango import Database
@@ -64,11 +64,11 @@ def __to_tango_type_fmt(value):
             shape_l = len(value.shape)
             if shape_l == 1:
                 dfmt = AttrDataFormat.SPECTRUM
-                max_dim_x = max(2**16, value.shape[0])
+                max_dim_x = max(2 ** 16, value.shape[0])
             elif shape_l == 2:
                 dfmt = AttrDataFormat.IMAGE
-                max_dim_x = max(2**16, value.shape[0])
-                max_dim_y = max(2**16, value.shape[1])
+                max_dim_x = max(2 ** 16, value.shape[0])
+                max_dim_y = max(2 ** 16, value.shape[1])
         else:
             dtype = CmdArgType.DevEncoded
     return dtype, dfmt, max_dim_x, max_dim_y
@@ -200,9 +200,7 @@ def create_tango_class(server, obj, tango_class_name=None, member_filter=None):
 
             pars = dict(name=name, dtype=dtype, dformat=fmt,
                         max_dim_x=x, max_dim_y=y, fget=read)
-            if read_only:
-                write = None
-            else:
+            if not read_only:
                 write.__name__ = "_write_" + name
                 pars['fset'] = write
                 setattr(DeviceDispatcher, write.__name__, write)
@@ -273,7 +271,7 @@ class Server:
         self.__tango_classes = _to_classes(tango_classes or [])
         self.__tango_devices = []
         if self.async_mode:
-            self.__worker = _create_async_worker(self.green_mode)
+            self.__worker = get_executor(self.green_mode)
         else:
             self.__worker = get_worker()
         set_worker(self.__worker)
@@ -319,9 +317,9 @@ class Server:
                 except:
                     self.log.info("Last time server was not properly "
                                   "shutdown!")
-            db_class_map, db_device_map = self.get_devices()
+            _, db_device_map = self.get_devices()
         else:
-            db_class_map, db_device_map = {}, {}
+            db_device_map = {}
 
         db_devices_add = {}
 
@@ -398,14 +396,8 @@ class Server:
 
         _add_classes(util, self.__tango_classes)
 
-        if async_mode:
-            tango_thread_id = self.worker.run_in_thread(self.__tango_loop)
-
     def __run(self, timeout=None):
-        if self.async_mode:
-            return self.worker.run(timeout=timeout)
-        else:
-            self.__tango_loop()
+        return self.worker.run(self.__tango_loop, wait=True, timeout=timeout)
 
     def __tango_loop(self):
         self.log.debug("server loop started")
@@ -415,7 +407,6 @@ class Server:
         self._phase = Server.Phase2
         self.log.info("Ready to accept request")
         u_instance.server_run()
-        self.worker.stop()
         if self.__auto_clean:
             self.__clean_up_process()
         self.log.debug("server loop exit")
@@ -516,10 +507,8 @@ class Server:
     def register_tango_device(self, klass, name):
         if inspect.isclass(klass):
             if isinstance(klass, Device):
-                kk, Device.TangoClassClass
-                k = Device
-                kname = Device.TangoClassName
-                # TODO: ??
+                # TODO
+                raise NotImplementedError
             else:
                 raise ValueError
         else:
