@@ -26,7 +26,7 @@ import collections
 from ._tango import StdStringVector, StdDoubleVector, \
     DbData, DbDevInfos, DbDevExportInfos, CmdArgType, AttrDataFormat, \
     EventData, AttrConfEventData, DataReadyEventData, DevFailed, constants, \
-    DevState, CommunicationFailed
+    DevState, CommunicationFailed, PipeEventData, DevIntrChangeEventData
 
 from . import _tango
 from .constants import AlrmValueNotSpec, StatusNotSet, TgLibVers
@@ -36,7 +36,7 @@ __all__ = [
     "requires_pytango", "requires_tango",
     "is_pure_str", "is_seq", "is_non_str_seq", "is_integer",
     "is_number", "is_scalar_type", "is_array_type", "is_numerical_type",
-    "is_int_type", "is_float_type", "is_bool_type", "is_bin_type",
+    "is_int_type", "is_float_type", "is_bool_type", "is_binary_type",
     "is_str_type", "obj_2_str", "seqStr_2_obj",
     "scalar_to_array_type",
     "document_method", "document_static_method", "document_enum",
@@ -47,7 +47,6 @@ __all__ = [
 
 __docformat__ = "restructuredtext"
 
-
 # Types
 
 _scalar_int_types = (
@@ -118,40 +117,40 @@ _binary_types = (
 
 def __build_to_tango_type():
     ret = {
-        int         : CmdArgType.DevLong64,
-        str         : CmdArgType.DevString,
-        bool        : CmdArgType.DevBoolean,
-        bytearray   : CmdArgType.DevEncoded,
-        float       : CmdArgType.DevDouble,
-        chr         : CmdArgType.DevUChar,
-        None        : CmdArgType.DevVoid,
+        int: CmdArgType.DevLong64,
+        str: CmdArgType.DevString,
+        bool: CmdArgType.DevBoolean,
+        bytearray: CmdArgType.DevEncoded,
+        float: CmdArgType.DevDouble,
+        chr: CmdArgType.DevUChar,
+        None: CmdArgType.DevVoid,
 
-        'int'       : CmdArgType.DevLong64,
-        'int16'     : CmdArgType.DevShort,
-        'int32'     : CmdArgType.DevLong,
-        'int64'     : CmdArgType.DevLong64,
-        'uint'      : CmdArgType.DevULong64,
-        'uint16'    : CmdArgType.DevUShort,
-        'uint32'    : CmdArgType.DevULong,
-        'uint64'    : CmdArgType.DevULong64,
-        'str'       : CmdArgType.DevString,
-        'string'    : CmdArgType.DevString,
-        'text'      : CmdArgType.DevString,
-        'bool'      : CmdArgType.DevBoolean,
-        'boolean'   : CmdArgType.DevBoolean,
-        'bytes'     : CmdArgType.DevEncoded,
-        'bytearray' : CmdArgType.DevEncoded,
-        'float'     : CmdArgType.DevDouble,
-        'float32'   : CmdArgType.DevFloat,
-        'float64'   : CmdArgType.DevDouble,
-        'double'    : CmdArgType.DevDouble,
-        'byte'      : CmdArgType.DevUChar,
-        'chr'       : CmdArgType.DevUChar,
-        'char'      : CmdArgType.DevUChar,
-        'None'      : CmdArgType.DevVoid,
-        'state'     : CmdArgType.DevState,
-        'enum'      : CmdArgType.DevEnum,
-        'blob'      : CmdArgType.DevPipeBlob,
+        'int': CmdArgType.DevLong64,
+        'int16': CmdArgType.DevShort,
+        'int32': CmdArgType.DevLong,
+        'int64': CmdArgType.DevLong64,
+        'uint': CmdArgType.DevULong64,
+        'uint16': CmdArgType.DevUShort,
+        'uint32': CmdArgType.DevULong,
+        'uint64': CmdArgType.DevULong64,
+        'str': CmdArgType.DevString,
+        'string': CmdArgType.DevString,
+        'text': CmdArgType.DevString,
+        'bool': CmdArgType.DevBoolean,
+        'boolean': CmdArgType.DevBoolean,
+        'bytes': CmdArgType.DevEncoded,
+        'bytearray': CmdArgType.DevEncoded,
+        'float': CmdArgType.DevDouble,
+        'float32': CmdArgType.DevFloat,
+        'float64': CmdArgType.DevDouble,
+        'double': CmdArgType.DevDouble,
+        'byte': CmdArgType.DevUChar,
+        'chr': CmdArgType.DevUChar,
+        'char': CmdArgType.DevUChar,
+        'None': CmdArgType.DevVoid,
+        'state': CmdArgType.DevState,
+        'enum': CmdArgType.DevEnum,
+        'blob': CmdArgType.DevPipeBlob,
     }
 
     try:
@@ -184,22 +183,23 @@ def __build_to_tango_type():
             ret[value] = key
     return ret
 
+
 TO_TANGO_TYPE = __build_to_tango_type()
 
 _scalar_to_array_type = {
-    CmdArgType.DevBoolean : CmdArgType.DevVarBooleanArray,
-    CmdArgType.DevUChar : CmdArgType.DevVarCharArray,
-    CmdArgType.DevShort : CmdArgType.DevVarShortArray,
-    CmdArgType.DevUShort : CmdArgType.DevVarUShortArray,
-    CmdArgType.DevInt : CmdArgType.DevVarLongArray,
-    CmdArgType.DevLong : CmdArgType.DevVarLongArray,
-    CmdArgType.DevULong : CmdArgType.DevVarULongArray,
-    CmdArgType.DevLong64 : CmdArgType.DevVarLong64Array,
-    CmdArgType.DevULong64 : CmdArgType.DevVarULong64Array,
-    CmdArgType.DevFloat : CmdArgType.DevVarFloatArray,
-    CmdArgType.DevDouble : CmdArgType.DevVarDoubleArray,
-    CmdArgType.DevString : CmdArgType.DevVarStringArray,
-    CmdArgType.ConstDevString : CmdArgType.DevVarStringArray,
+    CmdArgType.DevBoolean: CmdArgType.DevVarBooleanArray,
+    CmdArgType.DevUChar: CmdArgType.DevVarCharArray,
+    CmdArgType.DevShort: CmdArgType.DevVarShortArray,
+    CmdArgType.DevUShort: CmdArgType.DevVarUShortArray,
+    CmdArgType.DevInt: CmdArgType.DevVarLongArray,
+    CmdArgType.DevLong: CmdArgType.DevVarLongArray,
+    CmdArgType.DevULong: CmdArgType.DevVarULongArray,
+    CmdArgType.DevLong64: CmdArgType.DevVarLong64Array,
+    CmdArgType.DevULong64: CmdArgType.DevVarULong64Array,
+    CmdArgType.DevFloat: CmdArgType.DevVarFloatArray,
+    CmdArgType.DevDouble: CmdArgType.DevVarDoubleArray,
+    CmdArgType.DevString: CmdArgType.DevVarStringArray,
+    CmdArgType.ConstDevString: CmdArgType.DevVarStringArray,
 }
 
 # add derived scalar types to scalar to array map
@@ -207,7 +207,6 @@ for k, v in TO_TANGO_TYPE.items():
     if v in _scalar_to_array_type:
         _scalar_to_array_type[k] = _scalar_to_array_type[v]
 
-
 __NO_STR_VALUE = AlrmValueNotSpec, StatusNotSet
 
 __device_classes = None
@@ -350,7 +349,6 @@ try:
 except NameError:
     __str_klasses = str,
 
-
 __int_klasses = int,
 __number_klasses = numbers.Number,
 __seq_klasses = collections.Sequence, bytearray, StdStringVector
@@ -373,6 +371,7 @@ except NameError:
 
 if constants.NUMPY_SUPPORT:
     import numpy
+
     __int_klasses = tuple(list(__int_klasses) + [numpy.integer])
     __number_klasses = tuple(list(__number_klasses) + [numpy.number])
     __seq_klasses = tuple(list(__seq_klasses) + [numpy.ndarray])
@@ -384,10 +383,9 @@ __seq_klasses = tuple(__seq_klasses)
 
 
 def __get_tango_type(obj):
-    from .device_server import DataElement
     if is_non_str_seq(obj):
         tg_type, tg_format = get_tango_type(obj[0])
-        tg_format = AttrDataFormat(int(tg_format)+1)
+        tg_format = AttrDataFormat(int(tg_format) + 1)
         return tg_type, tg_format
     elif is_pure_str(obj):
         r = CmdArgType.DevString
@@ -403,7 +401,6 @@ def __get_tango_type(obj):
 
 
 def __get_tango_type_numpy_support(obj):
-    import numpy
     try:
         ndim, dtype = obj.ndim, str(obj.dtype)
         if ndim > 2:
@@ -518,6 +515,7 @@ def is_scalar(tg_type):
     global _scalar_types
     return tg_type in _scalar_types
 
+
 is_scalar_type = is_scalar
 
 
@@ -533,6 +531,7 @@ def is_array(tg_type):
     global _array_types
     return tg_type in _array_types
 
+
 is_array_type = is_array
 
 
@@ -555,6 +554,7 @@ def is_numerical(tg_type, inc_array=False):
         return False
     return tg_type in _array_numerical_types
 
+
 is_numerical_type = is_numerical
 
 
@@ -577,6 +577,7 @@ def is_int(tg_type, inc_array=False):
         return False
     return tg_type in _array_int_types
 
+
 is_int_type = is_int
 
 
@@ -599,6 +600,7 @@ def is_float(tg_type, inc_array=False):
         return False
     return tg_type in _array_float_types
 
+
 is_float_type = is_float
 
 
@@ -621,6 +623,7 @@ def is_bool(tg_type, inc_array=False):
         return False
     return tg_type in _array_bool_types
 
+
 is_bool_type = is_bool
 
 
@@ -643,10 +646,11 @@ def is_str(tg_type, inc_array=False):
         return False
     return tg_type in _array_str_types
 
+
 is_str_type = is_str
 
 
-def is_bin(tg_type, inc_array=False):
+def is_binary(tg_type, inc_array=False):
     """Tells if the given tango type is binary
 
     :param tg_type: tango type
@@ -658,10 +662,11 @@ def is_bin(tg_type, inc_array=False):
     :return: True if the given tango type is binary or False otherwise
     :rtype: :py:obj:`bool`
     """
-    global _scalar_bin_types
-    return tg_type in _scalar_bin_types
+    global _binary_types
+    return tg_type in _binary_types
 
-is_bin_type = is_bin
+
+is_binary_type = is_binary
 
 
 def seq_2_StdStringVector(seq, vec=None):
@@ -696,7 +701,8 @@ def StdStringVector_2_seq(vec, seq=None):
         :return: a python sequence filled with the same contents as seq
         :rtype: sequence<str>
     """
-    if seq is None: seq = []
+    if seq is None:
+        seq = []
     if not isinstance(vec, StdStringVector):
         raise TypeError('vec must be a tango.StdStringVector')
     for e in vec:
@@ -801,11 +807,13 @@ def seq_2_DbData(seq, vec=None):
         :rtype: :class:`tango.DbData`
     """
     if vec is None:
-        if isinstance(seq, DbData): return seq
+        if isinstance(seq, DbData):
+            return seq
         vec = DbData()
     if not isinstance(vec, DbData):
         raise TypeError('vec must be a tango.DbData')
-    for e in seq: vec.append(e)
+    for e in seq:
+        vec.append(e)
     return vec
 
 
@@ -839,11 +847,10 @@ def seqStr_2_obj(seq, tg_type, tg_format=None):
 
 
 def _seqStr_2_obj_from_type(seq, tg_type):
-
     if is_pure_str(seq):
         seq = seq,
 
-    #    Scalar cases
+    # Scalar cases
     global _scalar_int_types
     if tg_type in _scalar_int_types:
         return int(seq[0])
@@ -986,6 +993,8 @@ def obj_2_str(obj, tg_type=None):
             obj = obj[0]
         return str(obj)
     # sequence cases
+    if obj is None:
+        return ''
     return '\n'.join([str(i) for i in obj])
 
 
@@ -1064,6 +1073,7 @@ class CaselessList(list):
     Inherited methods :
     __imul__, __len__, __iter__, pop, reverse, sort
     """
+
     def __init__(self, inlist=[]):
         list.__init__(self)
         for entry in inlist:
@@ -1302,6 +1312,7 @@ class CaselessDict(dict):
     def keys(self):
         return CaselessList(dict.keys(self))
 
+
 __DEFAULT_FACT_IOR_FILE = "/tmp/rdifact.ior"
 __BASE_LINE = "notifd"
 __END_NOTIFD_LINE = "/DEVICE/notifd:"
@@ -1385,14 +1396,14 @@ def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
               "to TANGO database", file=out)
 
 
-class EventCallBack(object):
+class EventCallback(object):
     """
     Useful event callback for test purposes
 
     Usage::
 
         >>> dev = tango.DeviceProxy(dev_name)
-        >>> cb = tango.utils.EventCallBack()
+        >>> cb = tango.utils.EventCallback()
         >>> id = dev.subscribe_event("state", tango.EventType.CHANGE_EVENT, cb, [])
         2011-04-06 15:33:18.910474 sys/tg_test/1 STATE CHANGE [ATTR_VALID] ON
 
@@ -1438,7 +1449,7 @@ class EventCallBack(object):
         import datetime
         now = datetime.datetime.now()
         try:
-            date = evt.get_date().todatetime()
+            date = self._get_date(evt)
         except:
             date = now
         try:
@@ -1461,9 +1472,9 @@ class EventCallBack(object):
             value = self._get_value(evt)
         except Exception as e:
             value = "Unexpected exception in getting event value: %s" % str(e)
-        d = { "date" : date, "reception_date" : reception_date,
-              "type" : evt_type, "dev_name" : dev_name, "name" : attr_name,
-              "value" : value }
+        d = {"date": date, "reception_date": reception_date,
+             "type": evt_type, "dev_name": dev_name, "name": attr_name,
+             "value": value}
         print(self._msg.format(**d), file=self._fd)
 
     def _append(self, evt):
@@ -1473,6 +1484,14 @@ class EventCallBack(object):
             evts.pop(0)
         evts.append(evt)
 
+    def _get_date(self, evt):
+        if isinstance(evt, EventData):
+            return evt.attr_value.time.todatetime()
+        elif isinstance(evt, PipeEventData):
+            return evt.pipe_value.time.todatetime()
+        else:
+            return evt.get_date().todatetime()
+
     def _get_value(self, evt):
         """Internal usage only"""
         if evt.err:
@@ -1487,6 +1506,11 @@ class EventCallBack(object):
             return "label='%s'; unit='%s'" % (cfg.label, cfg.unit)
         elif isinstance(evt, DataReadyEventData):
             return ""
+        elif isinstance(evt, PipeEventData):
+            return evt.pipe_value
+        elif isinstance(evt, DevIntrChangeEventData):
+            print("utils::_get_value()")
+            return
 
 
 def get_home():
@@ -1568,7 +1592,7 @@ def from_version_str_to_hex_str(version_str):
 
 
 def from_version_str_to_int(version_str):
-    return int(from_version_str_to_hex_str(version_str, 16))
+    return int(from_version_str_to_hex_str(version_str), 16)
 
 
 def info():
